# Testpackage

[![Apache2.0 License](https://img.shields.io/badge/License-Apatch2.0-green.svg?style=for-the-badge)](https://choosealicense.com/licenses/apache-2.0/)

vscode, Github, poetryを使ったpythonの環境設定とパッケージ作成のテスト

## Acknowledgements

参考にしたWebページの詳細はNotionにまとめている

 - [Notion: Python環境設定](https://pool-laser-119.notion.site/Python-343c10792d3744c6b6c8ccf12335d5bb)

## Documentation

Sphinxで作成したドキュメント

- [Documentation](https://linktodocumentation)


## Usage/Examples

```python
import testpackageforjoblibsigma

function App() {
  return <Component />
}
```


## Running Tests

To run tests, run the following command

```bash
  npm run test
```


## Authors

- [@tk-tanab](https://github.com/tk-tanab)


## License

- [Apatch2.0](https://choosealicense.com/licenses/apache-2.0/)

